@@ -37,3 +37,5 @@ class Product(BaseModel):
     category: Optional[str]
     date_first_avail: Optional[str]
     customize: Optional[bool]
+    images: Optional[list]
+    aplus: Optional[bool]
