@@ -504,26 +504,29 @@ def parse_customize(p: Product, html: str = None):
 
 
 def parse_images(p: Product, selector: parsel.Selector = None):
-    images = selector.re_first(r"'colorImages': { 'initial': (\[.*\])},")
-    if images is None:
-        p.images = None
-        return
+    def l1() -> list:
+        images_block = selector.re_first(r"'colorImages': { 'initial': (\[.*\])},")
+        if images_block is None:
+            return list()
+        images_block = re.findall(r'"main":{.*?}', images_block)
+        if len(images_block) == 0:
+            return list()
 
-    images = re.findall(r'"main":{.*?}', images)
+        images_urls = list()
+        for image in images_block:
+            urls = re.findall(r'"(https.*?)"', image)
+            if len(urls) > 0:
+                images_urls.append(urls[-1])
+        return images_urls
+
+    def l2() -> list:
+        return selector.re(r'"mainUrl":"(.*?)"')
+
+    images = l1() or l2()
     if len(images) == 0:
         p.images = None
-        return
-
-    images_urls = list()
-    for image in images:
-        urls = re.findall(r'"(https.*?)"', image)
-        if len(urls) > 0:
-            images_urls.append(urls[-1])
-
-    if len(images_urls) == 0:
-        p.images = None
     else:
-        p.images = images_urls
+        p.images = images
 
 
 def parse_aplus(p: Product, selector: parsel.Selector = None):
